function varargout = gui_seawinds(varargin)
% Boots-up SeaWinds GUI, interacts with user via interface.
% gui_seawinds M-file for gui_seawinds.fig
%
% INPUT(S):
%
%   [none]
%
% OUTPUT(S):
%
%   h -- (optional) GUI handle
%
% OPeNDAP Science Team
% Copyright 2007, 2008
% $Version 2.0.0$

%==========================================================================
% Christian Buckingham
%
% REVISION HISTORY:
% 2007/01/01 0.x.x created, ceb
% 2007/xx/xx 0.x.x obtained every data file's attributes, scales 
%            accordingly, ceb
% 2007/12/21 0.x.x request variable now matches other guis, ceb
% 2008/02/15 1.2.0 (beta) added "satellite times can be tricky" button, ceb
% 2008/02/28 2.0.0 minor corrections, preparing for distribution, ceb
% 2008/06/15 modified for compiled version, ceb
%==========================================================================

warning('off','MATLAB:dispatcher:InexactMatch');
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_seawinds_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_seawinds_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
    %gui_State.gui_Name = 'gui_seawinds
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT
warning('on','MATLAB:dispatcher:InexactMatch');

% --- Executes just before gui_seawinds is made visible.
function gui_seawinds_OpeningFcn(hObject, eventdata, handles, varargin)

% Define handles "openfigure" field.
if ~isfield(handles,'openfigure')
    % Set available dates.
    DateSet(hObject, eventdata, handles)
    handles = guidata(hObject); %update "handles" variable
    handles.openfigure = 0; %set equal to zero on the first time.
end

% Set interface name.
filename = 'get_seawinds';
txt = ['NASA/REASoN Ocean Data Portal - '];
tmp1 = ['SeaWinds GUI'];
tmp2 = '';
txt = [txt,tmp1];
if (~isdeployed)
    tmp2 = strrep(op_version('mfile',filename),'Version ','');
    txt = [txt,' (Ver ',tmp2,')'];
end
set(hObject,'Name',txt);

% % Set "SaveFiles" off. (THIS IS TEMPORARY ... 31 MARCH 2007)
% set(handles.radiobuttonToFiles,'Enable','Off');

% % Set "SaveWorkspace" off.
% set(handles.radiobuttonInWksp,'Value',0);
% set(handles.radiobuttonToFiles,'Value',1);
% set(handles.radiobuttonInWksp,'Enable','Off');
% set(handles.popupmenuMode,'Enable','Off');
%.shp -- ESRI Shape File format (3 files)

% Set checkbox off.
set(handles.checkbox24,'Value',1);
set(handles.checkbox24,'Visible','Off');

% Set logos.
LogoSet(hObject, eventdata, handles)

% Set ToolTipString.
ToolTipSet(hObject, eventdata, handles)

% Enable or disable certain objects.
if get(handles.radiobuttonQuikSCAT,'value')
radiobuttonQuikSCAT_Callback(hObject, eventdata, handles)
else
radiobuttonADEOS_Callback(hObject, eventdata, handles)
end

% Set Pass text.
set(handles.checkboxPassAscending,'string','ascending: ~6:00 am LST');
set(handles.checkboxPassDescending,'string','descending: ~6:00 pm LST');

% Rename "File type:" to "Filename prefix:" and bring prefix field to
% front.
set(handles.text30,'string','Filename prefix:')
set(handles.popupmenu3,'visible','off')
set(handles.editFileNamePrefix,'visible','on') %prefix edit field
if get(handles.popupmenuMode,'value')==2
    set(handles.checkbox110,'enable','on')
end
if get(handles.popupmenuMode,'value')==1
    set(handles.checkbox110,'enable','off')
end

% Make 'Load Last Request' button inactive when file gui_xxx_request.mat is
% absent.
if ~exist('gui_seawinds_request.mat','file') 
    set(handles.pushbuttonLoadLastRequest,'Enable','Off')
end

% Set color of "Get Data" button.
%set(handles.pushbuttonGetData,'Enable','Off');
set(handles.pushbuttonGetData,'BackgroundColor',[0 1. 0.25]);

% Set color of data documentation button.
Color = get(hObject,'Color');
set(handles.pushbuttonNASAjpl,'BackgroundColor',Color)

% Set color of "served by" button.
Color = get(hObject,'Color');
set(handles.pushbuttonpodaac,'BackgroundColor',Color)

% Update handles "openfigure" field.
handles.openfigure = 1;

% Enable or disable "directory" and "prefix edit objects.
SaveFilesOnOff(handles.radiobuttonToFiles,[],handles)

% Choose default command line output for gui_seawinds
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);
%==========================================================================
% --- Outputs from this function are returned to the command line.
function varargout = gui_seawinds_OutputFcn(hObject, eventdata, handles)
varargout{1} = handles.output;
%==========================================================================
function checkbox101_Callback(hObject, eventdata, handles)
function editTime1yyyy_CreateFcn(hObject, eventdata, handles)
function editTime1yyyy_Callback(hObject, eventdata, handles)
function editTime1mm_CreateFcn(hObject, eventdata, handles)
function editTime1mm_Callback(hObject, eventdata, handles)
function editTime1dd_CreateFcn(hObject, eventdata, handles)
function editTime1dd_Callback(hObject, eventdata, handles)
function editTime2yyyy_CreateFcn(hObject, eventdata, handles)
function editTime2yyyy_Callback(hObject, eventdata, handles)
function editTime2mm_CreateFcn(hObject, eventdata, handles)
function editTime2mm_Callback(hObject, eventdata, handles)
function editTime2dd_CreateFcn(hObject, eventdata, handles)
function editTime2dd_Callback(hObject, eventdata, handles)
function editLat1_CreateFcn(hObject, eventdata, handles)
function editLat1_Callback(hObject, eventdata, handles)
function editLat2_CreateFcn(hObject, eventdata, handles)
function editLat2_Callback(hObject, eventdata, handles)
function editLon1_CreateFcn(hObject, eventdata, handles)
function editLon1_Callback(hObject, eventdata, handles)
function editLon2_CreateFcn(hObject, eventdata, handles)
function editLon2_Callback(hObject, eventdata, handles)
function editLatStep_CreateFcn(hObject, eventdata, handles)
function editLatStep_Callback(hObject, eventdata, handles)
function editLonStep_CreateFcn(hObject, eventdata, handles)
function editLonStep_Callback(hObject, eventdata, handles)
function editDirectoryName_CreateFcn(hObject, eventdata, handles)
function editDirectoryName_Callback(hObject, eventdata, handles)
function editFileNamePrefix_CreateFcn(hObject, eventdata, handles)
function editFileNamePrefix_Callback(hObject, eventdata, handles)
function editTimeStep_CreateFcn(hObject, eventdata, handles)
function editTimeStep_Callback(hObject, eventdata, handles)
function checkbox102_Callback(hObject, eventdata, handles)
function checkbox103_Callback(hObject, eventdata, handles)
function checkbox104_Callback(hObject, eventdata, handles)
function checkbox105_Callback(hObject, eventdata, handles)
function checkbox106_Callback(hObject, eventdata, handles)
function checkbox107_Callback(hObject, eventdata, handles)
function checkbox108_Callback(hObject, eventdata, handles)
function checkbox109_Callback(hObject, eventdata, handles)
function checkbox110_Callback(hObject, eventdata, handles)
function checkbox111_Callback(hObject, eventdata, handles)
function checkbox112_Callback(hObject, eventdata, handles)
function checkbox113_Callback(hObject, eventdata, handles)
function checkbox201_Callback(hObject, eventdata, handles)
function checkbox202_Callback(hObject, eventdata, handles)
function checkbox203_Callback(hObject, eventdata, handles)
function checkbox204_Callback(hObject, eventdata, handles)
function checkbox205_Callback(hObject, eventdata, handles)
function checkbox206_Callback(hObject, eventdata, handles)
function checkbox207_Callback(hObject, eventdata, handles)
function checkbox208_Callback(hObject, eventdata, handles)
function checkboxPassAscending_Callback(hObject, eventdata, handles)
function checkboxPassDescending_Callback(hObject, eventdata, handles)
function radiobuttonInWksp_Callback(hObject, eventdata, handles)

% tmp = get(handles.radiobuttonInWksp,'value');
% if tmp == 1
%     set(handles.radiobuttonToFiles,'value',0);
% end

function popupmenuMode_Callback(hObject, eventdata, handles)

if get(handles.popupmenuMode,'value')==2
    set(handles.checkbox110,'enable','on')
    set(handles.checkbox110,'value',1)
end
if get(handles.popupmenuMode,'value')==1
    set(handles.checkbox110,'enable','off')
    set(handles.checkbox110,'value',0)
end

function popupmenuMode_CreateFcn(hObject, eventdata, handles)
% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function checkbox24_Callback(hObject, eventdata, handles)
%==========================================================================
function radiobuttonQuikSCAT_Callback(hObject, eventdata, handles)
% This function executes when radiobuttonQuikSCAT is pressed.
% Enables and disables some functions.
h=handles;
set(h.radiobuttonQuikSCAT,'value',1);
set(h.radiobuttonADEOS,'value',0);
DateSet(hObject, eventdata, handles)
% set(h.checkboxPassAscending,'string','6:00 a.m. (local sun time)-asc');
% set(h.checkboxPassDescending,'string','6:00 p.m. (local sun time)-des');
set(h.checkboxPassAscending,'string','ascending: ~6:00 am LST');
set(h.checkboxPassDescending,'string','descending: ~6:00 pm LST');

%quikscat
set(h.checkbox104,'Enable','On')
%set(h.checkbox110,'Enable','On')

% adeos
set(h.checkbox107,'Enable','Off')
set(h.checkbox108,'Enable','Off')
set(h.checkbox111,'Enable','Off')
set(h.checkbox112,'Enable','Off')
set(h.checkbox113,'Enable','Off')
%==========================================================================
function radiobuttonADEOS_Callback(hObject, eventdata, handles)
% This function executes when radiobuttonADEOS is pressed.
% Enables and disables some functions.
h=handles;
set(h.radiobuttonQuikSCAT,'value',0);
set(h.radiobuttonADEOS,'value',1);
DateSet(hObject, eventdata, handles)
% set(h.checkboxPassAscending,'string','10:30 p.m. (local sun time)-asc');
% set(h.checkboxPassDescending,'string','10:30 a.m. (local sun time)-des');
set(h.checkboxPassAscending,'string','ascending: ~10:30 am LST');
set(h.checkboxPassDescending,'string','descending: ~10:30 pm LST');

%quikscat
set(h.checkbox104,'Enable','Off')
%set(h.checkbox110,'Enable','Off')

% adeos
set(h.checkbox107,'Enable','On')
set(h.checkbox108,'Enable','On')
set(h.checkbox111,'Enable','On')
set(h.checkbox112,'Enable','On')
set(h.checkbox113,'Enable','On')
%==========================================================================
function radiobuttonToFiles_Callback(hObject, eventdata, handles)
if get(handles.radiobuttonToFiles,'Value') == 0
    set(handles.editDirectoryName,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
    set(handles.editFileNamePrefix,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
elseif get(handles.radiobuttonToFiles,'Value') == 1
    set(handles.editDirectoryName,'BackgroundColor',[1. 1. 1.],'Enable','On')
    set(handles.editFileNamePrefix,'BackgroundColor',[1. 1. 1.],'Enable','On')
end

% tmp = get(handles.radiobuttonToFiles,'value');
% if tmp == 1
%     set(handles.radiobuttonInWksp,'value',0);
% end
%==========================================================================
function pushbuttonBrowse_Callback(hObject, eventdata, handles)
if get(handles.radiobuttonToFiles,'Value') == 1
txt = get(handles.editDirectoryName,'string');
if isempty(txt), txt = pwd; end
DIRNAME=uigetdir(txt,'Select a Directory for Downloading Files');
if isnumeric(DIRNAME)
    DIRNAME = ''; %txt;
end
set(handles.editDirectoryName,'String',DIRNAME)
end
%==========================================================================
% The main button that starts data acquisition
function pushbuttonGetData_Callback(hObject, eventdata, handles)

% Turn off ability to repress "Get Data" button.
%set(hObject,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off','String','Please wait...');
set(hObject,'Enable','Off','String','Please wait...');
pause(.5)

% Get input from user.
request=InputGet(hObject, eventdata, handles);

% Check input.
[msg,err,request]=interimdatacheck(request,handles.available_dates);
if (err)
    disp(msg);
    errordlg(msg);
    set(hObject,'Enable','On','String','Get Data');
    return
end

% Save request to .mat file.
filename = 'gui_seawinds_request.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname)-length(mfilename)); %mfilename does not have .m in it
    filename = [pname,filename];
end
save(filename,'request','-mat')

% Set "load last request" button to "on" (or enable).
set(handles.pushbuttonLoadLastRequest,'Enable','On')

% If it passes inspection, send down to user's workspace
% as variable "request".
assignin('base','request',request);

% Get data.
get_seawinds(request,hObject); %the second input means that it is called by the gui.

% Re-enable button after obtaining data.
set(hObject,'Enable','On','String','Get Data','BackgroundColor',[0 1. 0.25])

%==========================================================================
function pushbuttonNASAjpl_Callback(hObject, eventdata, handles)
url = 'http://podaac-www.jpl.nasa.gov/quikscat/qscat_doc.html';
web(url,'-browser')
% url = 'http://podaac-www.jpl.nasa.gov/seawinds/seawinds_doc.html';
% web(url,'-browser')
%==========================================================================
function pushbuttonOpendap_Callback(hObject, eventdata, handles)
url = 'http://www.opendap.org/';
web(url,'-browser')
%==========================================================================
function request=InputGet(hObject, eventdata, handles)
% This function obtains inputs from gui.
h=handles;

% DataType.
DataType=struct('name',[],'value',[]);
DataType.name={'quikscat','adeos'};
m(1)=get(h.radiobuttonQuikSCAT,'value');
m(2)=get(h.radiobuttonADEOS,'value');
if (sum(m(:))==0), set(h.radiobuttonQuikSCAT,'value',1); m(1)=1; end
DataType.value=m;
clear m

% Field.
if (DataType.value(1)) %quikscat
Field=struct('name',[],'value',[]);
m(1)=get(h.checkbox103,'value');  %wind speed
m(2)=get(h.checkbox101,'value');  %wind u
m(3)=get(h.checkbox102,'value');  %wind v
m(4)=get(h.checkbox104,'value'); %wind speed sq.
m(5)=get(h.checkbox105,'value');  %time of day
m(6)=get(h.checkbox106,'value');  %rain flag
m(7)=get(h.checkbox109,'value');  %rain prob
m(8)=get(h.checkbox110,'value'); %counts per wvc

m(9)=get(h.checkbox201,'value');    %wind stress u (Large)
m(10)=get(h.checkbox202,'value');  %wind stress v (Large)
m(11)=get(h.checkbox203,'value');  %wind stress u (Liu)
m(12)=get(h.checkbox204,'value');  %wind stress v (Liu)
m(13)=get(h.checkbox205,'value');  %drag coef (Large)
m(14)=get(h.checkbox206,'value');  %drag coef (Liu)
m(15)=get(h.checkbox207,'value');  %rain flag
m(16)=get(h.checkbox208,'value');  %time of day
Field.value=m;
clear m
end
if (DataType.value(2)) %adeos
Field=struct('name',[],'value',[]);
m(1)=get(h.checkbox103,'value');  %wind speed
m(2)=get(h.checkbox101,'value');  %wind u
m(3)=get(h.checkbox102,'value');  %wind v
m(4)=get(h.checkbox107,'value'); %atten corr
m(5)=get(h.checkbox105,'value');  %time of day
m(6)=get(h.checkbox107,'value');  %rain prob
m(7)=get(h.checkbox108,'value');  %srad rain rate
m(8)=get(h.checkbox113,'value'); %amsr rain indicator
m(9)=get(h.checkbox106,'value'); %rain flag
m(10)=get(h.checkbox112,'value'); %null data indicator
m(11)=get(h.checkbox111,'value'); %grid cell quality flag

m(12)=get(h.checkbox201,'value');   %wind stress u (Large)
m(13)=get(h.checkbox202,'value'); %wind stress v (Large)
m(14)=get(h.checkbox203,'value'); %wind stress u (Liu)
m(15)=get(h.checkbox204,'value');  %wind stress v (Liu)
m(16)=get(h.checkbox205,'value');  %drag coef (Large)
m(17)=get(h.checkbox206,'value');  %drag coef (Liu)
m(18)=get(h.checkbox207,'value');  %rain flag
m(19)=get(h.checkbox208,'value');  %time of day
Field.value=m;
clear m
end %adeos

% Pass.
Pass=struct('name',[],'value',[]);
m(1)=get(h.checkboxPassAscending,'value'); %ascending
m(2)=get(h.checkboxPassDescending,'value'); %descending
Pass.value=m;
clear m

% Attributes.
Attributes=get(h.checkbox24,'value');

% DATE1.
yyyy=get(h.editTime1yyyy,'string');
mm=get(h.editTime1mm,'string'); if (length(mm)==1); mm=['0',mm]; end
dd=get(h.editTime1dd,'string'); if (length(dd)==1); dd=['0',dd]; end
DATE1=[yyyy,mm,dd];

% DATE2.
yyyy=get(h.editTime2yyyy,'string');
mm=get(h.editTime2mm,'string'); if (length(mm)==1); mm=['0',mm]; end
dd=get(h.editTime2dd,'string'); if (length(dd)==1); dd=['0',dd]; end
DATE2=[yyyy,mm,dd];

% DATEINC.
DATEINC=get(h.editTimeStep,'string');

% LAT1.
LAT1=get(h.editLat1,'string');

% LAT2.
LAT2=get(h.editLat2,'string');

% LON1.
LON1=get(h.editLon1,'string');

% LON2.
LON2=get(h.editLon2,'string');

% LATINC & LONINC.
LATINC=get(h.editLatStep,'string');
LONINC=get(h.editLonStep,'string');

% SaveWorkspace, SaveFile, Other.
SaveWorkspace=get(h.radiobuttonInWksp,'value');
tmp=get(h.popupmenuMode,'string');
SaveWorkspaceMode=tmp{get(h.popupmenuMode,'value')};
SaveFile=get(h.radiobuttonToFiles,'value');
directory=get(h.editDirectoryName,'string');
if (~isempty(directory)),
    if (strcmp(directory(end),'\') || strcmp(directory(end),'/')),
        directory=directory(1:end-1);
    end
end
directory = directory;
prefx=get(h.editFileNamePrefix,'string');
%Other={directory,prefx};

% SaveFileType.
tmp=get(h.popupmenu3,'string');
SaveFileType = tmp{get(h.popupmenu3,'value')};

% Request Vector.
request = struct('DATE1',DATE1,...
                 'DATE2',DATE2,...
                 'DATEINC',DATEINC,...
                 'LAT1',LAT1,...
                 'LAT2',LAT2,...
                 'LATINC',LATINC,...
                 'LON1',LON1,...
                 'LON2',LON2,...
                 'LONINC',LONINC,...
                 'DataType',DataType,...
                 'Field',Field,...
                 'Pass',Pass,...
                 'Attributes',Attributes,...
                 'SaveWorkspace',SaveWorkspace,...
                 'SaveWorkspaceMode',SaveWorkspaceMode,...
                 'SaveFile',SaveFile,...
                 'SaveFileType',SaveFileType,...
                 'DIRNAME',directory,...
                 'FNPREFIX',prefx);
                 
%==========================================================================
function InputSet(hObject, eventdata, handles, request)
% This function sets the gui.
h = handles;

% Parse vector.
DATE1 = request.DATE1;
DATE2 = request.DATE2;
DATEINC = request.DATEINC;
LAT1 = request.LAT1;
LAT2 = request.LAT2;
LATINC = request.LATINC;
LON1 = request.LON1;
LON2 = request.LON2;
LONINC = request.LONINC;
DataType = request.DataType;
Field = request.Field;
Pass = request.Pass;
Attributes = request.Attributes;
SaveWorkspace = request.SaveWorkspace;
SaveWorkspaceMode = request.SaveWorkspaceMode;
SaveFile = request.SaveFile;
SaveFileType = request.SaveFileType;
directory = request.DIRNAME;
prefx = request.FNPREFIX;

% Dates.
if (isempty(DATE1))
set(h.editTime1yyyy,'string','');
set(h.editTime1mm,'string','');
set(h.editTime1dd,'string','');
else
set(h.editTime1yyyy,'string',DATE1(1:4));
set(h.editTime1mm,'string',DATE1(5:6));
set(h.editTime1dd,'string',DATE1(7:8));
end

if (isempty(DATE2))
set(h.editTime2yyyy,'string','');
set(h.editTime2mm,'string','');
set(h.editTime2dd,'string','');
else
set(h.editTime2yyyy,'string',DATE2(1:4));
set(h.editTime2mm,'string',DATE2(5:6));
set(h.editTime2dd,'string',DATE2(7:8));
end

set(h.editTimeStep,'string',DATEINC);

% Latitudes & Longitudes.
set(h.editLat1,'string',LAT1);
set(h.editLat2,'string',LAT2);
set(h.editLon1,'string',LON1);
set(h.editLon2,'string',LON2);
set(h.editLatStep,'string',LATINC);
set(h.editLonStep,'string',LONINC);

% DataType.
set(h.radiobuttonQuikSCAT,'value',DataType.value(1)); %quikscat
set(h.radiobuttonADEOS,'value',DataType.value(2)); %adeos

% Available time range.
if DataType.value(2)
    DateSet(hObject, eventdata, handles);
end

% Field.
if (DataType.value(1)) %quikscat
n=1;
set(h.checkbox103,'value',Field.value(n)); n=n+1; %wind speed
set(h.checkbox101,'value',Field.value(n)); n=n+1; %wind u
set(h.checkbox102,'value',Field.value(n)); n=n+1; %wind v
set(h.checkbox104,'value',Field.value(n)); n=n+1;%wind speed sq.
set(h.checkbox105,'value',Field.value(n)); n=n+1; %time of day
set(h.checkbox106,'value',Field.value(n)); n=n+1; %rain flag
set(h.checkbox109,'value',Field.value(n)); n=n+1; %rain prob
set(h.checkbox110,'value',Field.value(n)); n=n+1;%counts per wvc

set(h.checkbox201,'value',Field.value(n)); n=n+1;  %wind stress u (Large)
set(h.checkbox202,'value',Field.value(n)); n=n+1; %wind stress v (Large)
set(h.checkbox203,'value',Field.value(n)); n=n+1; %wind stress u (Liu)
set(h.checkbox204,'value',Field.value(n)); n=n+1; %wind stress v (Liu)
set(h.checkbox205,'value',Field.value(n)); n=n+1; %drag coef (Large)
set(h.checkbox206,'value',Field.value(n)); n=n+1; %drag coef (Liu)
set(h.checkbox207,'value',Field.value(n)); n=n+1; %rain flag
set(h.checkbox208,'value',Field.value(n)); n=n+1; %time of day

%quikscat
set(h.checkbox104,'Enable','On')
set(h.checkbox110,'Enable','On')

% adeos
set(h.checkbox107,'Enable','Off')
set(h.checkbox108,'Enable','Off')
set(h.checkbox111,'Enable','Off')
set(h.checkbox112,'Enable','Off')
set(h.checkbox113,'Enable','Off')
end

if (DataType.value(2)) %adeos
n=1;
set(h.checkbox103,'value',Field.value(n)); n=n+1;  %wind speed
set(h.checkbox101,'value',Field.value(n)); n=n+1;  %wind u
set(h.checkbox102,'value',Field.value(n)); n=n+1;  %wind v
set(h.checkbox107,'value',Field.value(n)); n=n+1; %atten corr
set(h.checkbox105,'value',Field.value(n)); n=n+1;  %time of day
set(h.checkbox109,'value',Field.value(n)); n=n+1;  %rain prob
set(h.checkbox108,'value',Field.value(n)); n=n+1;  %srad rain rate
set(h.checkbox113,'value',Field.value(n)); n=n+1; %amsr rain indicator
set(h.checkbox106,'value',Field.value(n)); n=n+1; %rain flag
set(h.checkbox112,'value',Field.value(n)); n=n+1; %null data indicator
set(h.checkbox111,'value',Field.value(n)); n=n+1; %grid cell quality flag

set(h.checkbox201,'value',Field.value(n)); n=n+1;   %wind stress u (Large)
set(h.checkbox202,'value',Field.value(n)); n=n+1; %wind stress v (Large)
set(h.checkbox203,'value',Field.value(n)); n=n+1; %wind stress u (Liu)
set(h.checkbox204,'value',Field.value(n)); n=n+1;  %wind stress v (Liu)
set(h.checkbox205,'value',Field.value(n)); n=n+1;  %drag coef (Large)
set(h.checkbox206,'value',Field.value(n)); n=n+1;  %drag coef (Liu)
set(h.checkbox207,'value',Field.value(n)); n=n+1;  %rain flag
set(h.checkbox208,'value',Field.value(n)); n=n+1;  %time of day

%quikscat
set(h.checkbox104,'Enable','Off')
set(h.checkbox110,'Enable','Off')

% adeos
set(h.checkbox107,'Enable','On')
set(h.checkbox108,'Enable','On')
set(h.checkbox111,'Enable','On')
set(h.checkbox112,'Enable','On')
set(h.checkbox113,'Enable','On')
end

% Pass.
n=1;
set(h.checkboxPassAscending,'value',Pass.value(n)); n=n+1; %wind speed
set(h.checkboxPassDescending,'value',Pass.value(n)); n=n+1; %wind u

% Attributes.
set(h.checkbox24,'value',Attributes);

% SaveWorkspace, SaveFile, SaveWorkspaceMode.
set(h.radiobuttonInWksp,'value',SaveWorkspace);
set(h.radiobuttonToFiles,'value',SaveFile);
set(h.editDirectoryName,'string',directory);
if ~isempty(prefx)
    set(h.editFileNamePrefix,'string',prefx);
end

% Native.
if strcmpi(SaveWorkspaceMode,'opendap')
    set(h.popupmenuMode,'value',1);
else
    set(h.popupmenuMode,'value',2);
end

if get(handles.popupmenuMode,'value')==2
    set(handles.checkbox110,'enable','on')
end
if get(handles.popupmenuMode,'value')==1
    set(handles.checkbox110,'enable','off')
end

% SaveFileType.
if strcmpi(SaveFileType,'.asc')
    set(h.popupmenu3,'value',2);
else
    set(h.popupmenu3,'value',1);
end
%==========================================================================
function pushbuttonLoadLastRequest_Callback(hObject, eventdata, handles)
% This function loads last request.
filename = 'gui_seawinds_request.mat';
if exist(filename,'file')
    load(filename)
else
    msgbox(['File ',filename,' does not exist.']);
    return
end

InputSet(hObject, eventdata, handles, request)
SaveFilesOnOff([], [], handles)
%==========================================================================
function SaveFilesOnOff(hObject, eventdata, handles)
% This function turns off and on the directory and prefix uiobjects.
if get(handles.radiobuttonToFiles,'Value') == 0
    set(handles.editDirectoryName,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
    set(handles.editFileNamePrefix,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
elseif get(handles.radiobuttonToFiles,'Value') == 1
    set(handles.editDirectoryName,'BackgroundColor',[1. 1. 1.],'Enable','On')
    set(handles.editFileNamePrefix,'BackgroundColor',[1. 1. 1.],'Enable','On')
end
%==========================================================================
function DateSet(hObject, eventdata, handles)
% This function obtains and sets the available date range.

if (~isfield(handles,'available_dates')) %metadata already obtained?

database_filename = 'gui_seawinds_filelist.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    database_filename = [pname,database_filename];
end

status = getseawinds_updatefilelist(database_filename);

% Load previous list of filenames and associated times.
load('-mat',database_filename);

% Construct dates.
date1 = datevec(tmat(1));
date2 = datevec(tmat(length(tmat)));

% Make text readable by GUI.
yyyy = num2str(date1(1),'%04d');
mm = num2str(date1(2),'%02d');
dd = num2str(date1(3),'%02d');
DATE1 = [yyyy,mm,dd];

yyyy = num2str(date2(1),'%04d');
mm = num2str(date2(2),'%02d');
dd = num2str(date2(3),'%02d');
DATE2 = [yyyy,mm,dd];

% We have not developed the code for ADEOS yet.
DATE3 = '20030410'; %adeos
DATE4 = '20031024'; %adeos
handles.available_dates={DATE1,DATE2,DATE3,DATE4};
guidata(hObject,handles); % store for later use.

else % if (~isfield(handles,'available_dates')) %metadata already obtained?
    
    DATE1=handles.available_dates{1};
    DATE2=handles.available_dates{2};
    
end

date1=[DATE1(1:4),'-',DATE1(5:6),'-',DATE1(7:8)];
date2=[DATE2(1:4),'-',DATE2(5:6),'-',DATE2(7:8)];
txt=['Available time range: [',date1,' to ',date2,']'];
set(handles.textTimeRange,'string',txt);

% Below this OLD!!

% if (~isfield(handles,'available_dates')) %metadata already obtained?
%     
% hbox=msgbox('Acquiring metadata from internet, please wait ...');
% hh=get(hbox,'Children'); %makes OK button invisible
% set(hh(2),'Visible','off');
% pause(.5);
% %[msg,err1,DATE1,DATE2]=qscat_get_dates;
% err1 = 1; % NEED TO WRITE A PROGRAM TO OBTAIN DATES.
% if (err1)
%     DATE1='19990719';
%     DATE2=strrep(datestr(now,29),'-','');
% end
% %[msg,err2,DATE3,DATE4]=adeos_get_dates;
% err2 = 1; % NEED TO WRITE A PROGRAM TO OBTAIN DATES.
% if (err2)
%     DATE3='20030410';
%     DATE4='20031024';
% end
% % if (err1 || err2)
% %     msg = ['We cannot make a connection to server. ',...
% %         'This might impede further progress. ',...
% %         'Using a default set of dates.']; % of ',...
% %     handle = warndlg(msg);
% %     uiwait(handle);
% %     disp(' ')
% % end
% close(hbox)
% handles.available_dates={DATE1,DATE2,DATE3,DATE4};
% guidata(hObject,handles);
% end% if already metadata not obtained.
% 
% qscat=get(handles.radiobuttonQuikSCAT,'Value');
% adeos=get(handles.radiobuttonADEOS,'Value');
% if (qscat)
%     DATE1=handles.available_dates{1};
%     DATE2=handles.available_dates{2};
%     date1=[DATE1(1:4),'-',DATE1(5:6),'-',DATE1(7:8)];
%     date2=[DATE2(1:4),'-',DATE2(5:6),'-',DATE2(7:8)];
% elseif (adeos)
%     DATE1=handles.available_dates{3};
%     DATE2=handles.available_dates{4};
%     date1=[DATE1(1:4),'-',DATE1(5:6),'-',DATE1(7:8)];
%     date2=[DATE2(1:4),'-',DATE2(5:6),'-',DATE2(7:8)];
% else
%     date1=['xxx'];
%     date2=['xxx'];
% end
% txt=['Available time range: [',date1,' to ',date2,']'];
% set(handles.textTimeRange,'string',txt);
%==========================================================================
function ToolTipSet(hObject, eventdata, handles)
% This function sets the tooltips.
txt=['The user can choose between QuikSCAT or ADEOS data. ',...
     'Currently, only QuikSCAT data are available. In addition, ',...
     'wind stress products are unavailable.'];
op_tooltipwrap(handles.radiobuttonQuikSCAT,txt,50);

txt=['Wind stress products are not available.'];
op_tooltipwrap(handles.text38,txt,50);

txt=['ADOES II scatterometer data.'];
op_tooltipwrap(handles.radiobuttonADEOS,txt,50);

txt=['Wind speed toward East, m/s.'];
op_tooltipwrap(handles.checkbox101,txt,50);

txt=['Wind speed toward North, m/s.'];
op_tooltipwrap(handles.checkbox102,txt,50);

txt=['Wind speed, m/s.'];
op_tooltipwrap(handles.checkbox103,txt,50);

txt=['Wind speed squared, m^2/s^2.'];
op_tooltipwrap(handles.checkbox104,txt,50);

txt=['Time of day, fractional day (0.9999 corresponds to 23:59:59 UTC).'];
op_tooltipwrap(handles.checkbox105,txt,50);

txt=['Rain flag. ',...
    'Values of 0 and 4 indicate the absence of rain. ',...
    'Values of 2 and 6 indicate the presence of rain. ',...
    'All other values (1,3,5,7) are times when the rain flag is not ',...
    'usable. Units = N/A.'];
op_tooltipwrap(handles.checkbox106,txt,50);

txt=['Attenuation correction.'];
op_tooltipwrap(handles.checkbox107,txt,50);

txt=['Rain rate. These rain rates are based on 13.402 GHz ',...
    'brightness temperatures generated using the noise energy ',...
    'level in the echo channel of the Seawinds instrument. Units = mm/hr.'];
op_tooltipwrap(handles.checkbox108,txt,50);

txt=['Rain probability (0 to 1).'];
op_tooltipwrap(handles.checkbox109,txt,50);

txt=['Number of wind measurements per wind vector cell. ',...
    'If value=0, wind speed at this location is null. ',...
    '(This is useful for discriminating between a zero wind measurement ',...
    'and a null value.) Units = counts.'];
op_tooltipwrap(handles.checkbox110,txt,50);

txt=['Grid cell qualtiy flag. ',...
    'Data is arranged in the form of bits. Use ',...
    'a decimal-to-binary conversion tool (e.g., "dec2bin") to convert the bits ',...
    'into a binary representation of the number. The bit length is ',...
    'twelve bits so that numbers greater 12 bits (4095 decimal) ',...
    'should be ignored. ',...
    'For detailed description, please see the data documentation link. ',...
    'Units = N/A.'];
op_tooltipwrap(handles.checkbox111,txt,50);

txt=['Null data indicator. If 0, data is usable. If 1 ',...
    'data data should not be used. Units = N/A.'];
op_tooltipwrap(handles.checkbox112,txt,50);

txt=['AMSR rain indicator. A nondimensional parameter ',...
    'that reflects the ambient atmospheric conditions. ',...
    'If less than 0.5, clear or cloudy conditions; atmosphere ',...
    'attenuates signal of satellite. ',...
    'If between 0.5 and 4.0, light to moderate rain; atmosphere ',...
    'attenuates signal. Most of attenuation due to precipitating ',...
    'hydrometeors. ',...
    'If greater than 4.0, heavy rains--backscatter generated by ',...
    'hydrometeors dominates surface echo signal; atmospheric attenuation ',...
    'less important by comparison. Units = N/A.'];
op_tooltipwrap(handles.checkbox113,txt,50);

% note=['NOTE: Wind stress estimates using the Large & Pond algorithm have ',...
%      'been found to be in error. JPL/PO.DAAC has recognized the error ',...
%      'and are in the process of correcting it. Estimated dates of reprocessed ',...
%      'wind stress are June 1, 2007. http://podaac-www.jpl.nasa.gov/ovwLTR.html.'];
 
txt=['Wind stress toward East, Large & Pond, N/m^2.'];
txt=[txt,' Note: there has been an error found in the ',...
    'Large & Pond wind stress product. ',...
    'Please check data distributor for updates.'];
op_tooltipwrap(handles.checkbox201,txt,50);

txt=['Wind stress toward North, Large & Pond, N/m^2.'];
txt=[txt,' Note: there has been an error found in the ',...
    'Large & Pond wind stress product. ',...
    'Please check data distributor for updates.'];
op_tooltipwrap(handles.checkbox202,txt,50);

txt=['Wind stress toward East, Liu & Tang, N/m^2.'];
op_tooltipwrap(handles.checkbox203,txt,50);

txt=['Wind stress toward North, Liu & Tang, N/m^2.'];
op_tooltipwrap(handles.checkbox204,txt,50);

txt=['Drag coefficient, Large & Pond.'];
op_tooltipwrap(handles.checkbox205,txt,50);

txt=['Drag coefficient, Liu & Tang.'];
op_tooltipwrap(handles.checkbox206,txt,50);

txt=['Rain flag. ',...
    'Values of 0 and 4 indicate the absence of rain. ',...
    'Values of 2 and 6 indicate the presence of rain. ',...
    'All other values (1,3,5,7) are times when the rain flag is not ',...
    'usable. Units = N/A. Caution: may be different from wind vector rain flag.'];
op_tooltipwrap(handles.checkbox207,txt,50);

txt=['Time of day, fractional day (0.9999 corresponds to 23:59:59 UTC).'];
op_tooltipwrap(handles.checkbox208,txt,50);

% txt=['Separate maps are created for both the ascending and descending passes. ',...
%     'The orbit is such that the ascending and descending equator ',...
%     'crossings are at local (mean sun) times of 6 AM and 6 PM, respectively ',...
%     '(10:30 PM and 10:30 AM for ADEOS). ',...
%     'Data which overlap on subsequent passes are overwritten, not averaged.'];
% op_tooltipwrap(handles.checkboxPassAscending,txt,50);
% op_tooltipwrap(handles.checkboxPassDescending,txt,50);

txt=['Data edge located at 0 degrees longitude.'];
op_tooltipwrap(handles.textLongitudeRange,txt,50);

txt=['Help'];
op_tooltipwrap(handles.pushbuttonInfo,txt,50);
%==========================================================================
function LogoSet(hObject, eventdata, handles)

% % Resize pushbuttons or axes.
% % Ratio of character height to character width for a square pixel on a PC.
% rr_pc = 0.3846; %7.692/20
% 
% % Ratio of character height to character width for a square pixel on a
% % maci. (The ibook-G4 mac is 7.692/20.)
% rr_maci = 0.5000; %10/20
% 
% scale_factor = 0.8300;
% 
% % Place logos on the GUI
% % Resize uicontrol objects.
% [img,MAP]=imread('logo_opendap.jpg');
% set(handles.pushbuttonOpendap,'CData',img)
% if ~handles.openfigure
%     if strcmpi(computer,'maci') || strcmpi(computer,'mac')
%     pos = get(handles.pushbuttonOpendap,'position'); %units will be in characters
%     set(handles.pushbuttonOpendap,'position',[pos(1),pos(2),scale_factor*pos(3),pos(4)]);
%     end
% end
% 
% [img,MAP]=imread('logo_nasa_jpl.jpg');
% set(handles.pushbuttonNASAjpl,'CData',img)
% if ~handles.openfigure
%     if strcmpi(computer,'maci') || strcmpi(computer,'mac')
%     pos = get(handles.pushbuttonNASAjpl,'position'); %units will be in characters
%     set(handles.pushbuttonNASAjpl,'position',[pos(1),pos(2),scale_factor*pos(3),pos(4)]);
%     end
% end

%==========================================================================
% Meri's code.
% Place logos on the GUI
% determine screen resolution and size of character in pixels
Units0=get(0,'Units'); % save initial settings
set(0,'Units','characters');
SSC=get(0,'ScreenSize'); % screen size in characters
set(0,'Units','pixels');
SSP=get(0,'ScreenSize'); % screen size in pixels
set(0,'Units',Units0); % restore to original units
ppcx=SSP(3)/SSC(3); % pixels per character along x
ppcy=SSP(4)/SSC(4); % pixels per character along y

[img,MAP]=imread('logo_opendap.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx; % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbuttonOpendap,'CData',img)
pos = get(handles.pushbuttonOpendap,'position'); %units will be in characters
set(handles.pushbuttonOpendap,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_nasa_jpl.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;
CY=(NY+12)/ppcy;
set(handles.pushbuttonNASAjpl,'CData',img)
pos = get(handles.pushbuttonNASAjpl,'position'); %units will be in characters
set(handles.pushbuttonNASAjpl,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_podaac.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;
CY=(NY+12)/ppcy;
set(handles.pushbuttonpodaac,'CData',img)
pos = get(handles.pushbuttonpodaac,'position'); %units will be in characters
set(handles.pushbuttonpodaac,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_questionmark.jpg');
% [NY,NX,N3]=size(img);
% CX=(NX+8)/ppcx;
% CY=(NY+12)/ppcy;
% set(handles.pushbuttonInfo,'CData',img)
% pos = get(handles.pushbuttonInfo,'position'); %units will be in characters
% set(handles.pushbuttonInfo,'position',[pos(1),pos(2),CX,CY]);
[N1,N2,N3]=size(img);
set(handles.pushbuttonInfo,'string','')
set(handles.pushbuttonInfo,'CData',img)
set(handles.pushbuttonInfo,'Units','pixels')
pos = get(handles.pushbuttonInfo,'position');
set(handles.pushbuttonInfo,'position',[pos(1) pos(2) N1 N2])

[img,MAP]=imread('logo_nasa1.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbuttonNASA,'CData',img)
pos = get(handles.pushbuttonNASA,'position'); %units will be in characters
set(handles.pushbuttonNASA,'position',[pos(1),pos(2),CX,CY]);  
%==========================================================================
function [msg,err,request]=interimdatacheck(varargin)
% Checks the user's inputs to make sure they makes sense.

% Revision history.
% 2008/02/18 modified to include a single latitude/single longitude grid pt

if nargin == 1
    request = varargin{1};
elseif nargin == 2
    request = varargin{1};
    dates = varargin{2};
else
    error('Number of inputs must be 1 or 2.')
end

% Parse vector.
DATE1 = request.DATE1;
DATE2 = request.DATE2;
DATEINC = request.DATEINC;
LAT1 = request.LAT1;
LAT2 = request.LAT2;
LATINC = request.LATINC;
LON1 = request.LON1;
LON2 = request.LON2;
LONINC = request.LONINC;
DataType = request.DataType;
Field = request.Field;
Pass = request.Pass;
Attributes = request.Attributes;
SaveWorkspace = request.SaveWorkspace;
SaveWorkspaceMode = request.SaveWorkspaceMode;
SaveFile = request.SaveFile;
SaveFileType = request.SaveFileType;
directory = request.DIRNAME;
prefx = request.FNPREFIX;

%% Check to make sure certain inputs exist.
if (~DataType.value(1) && ~DataType.value(2)) %instrument2
    err=1;
    msg='An instrument (QuikSCAT, ADEOS II) has not been selected. Please correct and try again.';
    return
end
len=length(Field.value);
if (sum(Field.value(1:len))==0)
    err=1;
    msg='Parameters (Wind Vectors, Winds Stress) have not been selected. Please correct and try again.';
    return
end
if (isempty(DATE1) || isempty(DATE2))
    err=1;
    msg='A date range has not been entered. Please correct and try again.';
    return
end
if (length(DATE1)~=8)
    err=1;
    msg='The chosen dates have not been entered correctly. Please correct and try again.';
    return
end
if (length(DATE2)~=8)
    err=1;
    msg='The chosen dates have not been entered correctly. Please correct and try again.';
    return
end
len=length(Pass.value);
if (sum(Pass.value(1:len))==0)
    err=1;
    msg='A pass (ascending, descending) has not been selected. Please correct and try again.';
    return
end
if (isempty(LAT1) || isempty(LAT2))
    err=1;
    msg='A latitude range has not been entered. Please correct and try again.';
    return
end
if (isempty(LON1) || isempty(LON2))
    err=1;
    msg='A longitude range has not been entered. Please correct and try again.';
    return
end
if (isempty(DATEINC))
    err=1;
    msg='A time step has not been entered. Please correct and try again.';
    return
end
if (isempty(LATINC))
    err=1;
    msg='A latitude step has not been entered. Please correct and try again.';
    return
end
if (isempty(LONINC))
    err=1;
    msg='A longitude step has not been entered. Please correct and try again.';
    return
end
if (~SaveWorkspace && ~SaveFile)
    err=1;
    msg='An output type has not been selected. Please choose an ouput type.';
    return
end

%% DATE1, DATE2.
% Instrument dates.
if (exist('dates','var'))
    START_INSTRUMENT1 = dates{1};
    END_INSTRUMENT1 = dates{2};
    START_INSTRUMENT2 = dates{3};
    END_INSTRUMENT2 = dates{4};    
else
    [msg,err,START_INSTRUMENT1,END_INSTRUMENT1]=qscat_get_dates;
    if (err)
        disp(msg);
        errordlg(msg);
        return
    end
    [msg,err,START_INSTRUMENT2,END_INSTRUMENT2]=adeos_get_dates;
    if (err)
        disp(msg);
        errordlg(msg);
        return
    end
end

% User dates.
date1vec=[str2num(DATE1(1:4)),str2num(DATE1(5:6)),str2num(DATE1(7:8))];
date2vec=[str2num(DATE2(1:4)),str2num(DATE2(5:6)),str2num(DATE2(7:8))];
date1=datenum(date1vec);
date2=datenum(date2vec);

% Instrument dates revisited.
start1vec=[str2num(START_INSTRUMENT1(1:4)),str2num(START_INSTRUMENT1(5:6)),str2num(START_INSTRUMENT1(7:8))];
start2vec=[str2num(START_INSTRUMENT2(1:4)),str2num(START_INSTRUMENT2(5:6)),str2num(START_INSTRUMENT2(7:8))];
end1vec=[str2num(END_INSTRUMENT1(1:4)),str2num(END_INSTRUMENT1(5:6)),str2num(END_INSTRUMENT1(7:8))];
end2vec=[str2num(END_INSTRUMENT2(1:4)),str2num(END_INSTRUMENT2(5:6)),str2num(END_INSTRUMENT2(7:8))];
start1=datenum(start1vec);
start2=datenum(start2vec);
end1=datenum(end1vec);
end2=datenum(end2vec);

% Compare dates.
err=0;
msg='';
if (DataType.value(1)) %instrument1
ok_main_a = (start1 <= date1) && (date1 <= end1); %date1 contained in data record.
ok_main_b = (start1 <= date2) && (date2 <= end1); %date2 contained in data record.
ok_main_c = (date1 <= date2);
end
if (DataType.value(2)) %instrument2
ok_adeos_a = (start2 <= date1) && (date1 <= end2); %date1 contained in instrument2 data record.
ok_adeos_b = (start2 <= date2) && (date2 <= end2); %date2 contained in instrument2 data record.
ok_main_c = (date1 <= date2);
end

if (DataType.value(1)) %instrument1
err_date = ~(ok_main_a && ok_main_b && ok_main_c);
if err_date
    err=1;
    msg='Dates entered are not valid. Please correct and re-enter.';
    return
end
end
if (DataType.value(2)) %instrument2
ok_adeos = (ok_adeos_a && ok_adeos_b && ok_main_c);
if ~ok_adeos
    err=1;
    msg='Dates entered are not valid. Please correct and re-enter.';
    return
end
end

%% LAT1, LAT2, LON1, LON2.
start1 = -90; %latitude
start2 = 0;   %longitude
end1 = +90;   %latitude
end2 = 360;   %longitude
lat1=str2num(LAT1);
lat2=str2num(LAT2); 
lon1=str2num(LON1);
lon2=str2num(LON2);
if (lon1<=-180),
    lon1=-180+.125;
    LON1='-180';
    %LON1=num2str(-180);
end
if (lon2>=360),
    lon2=360-.125;
    LON2='360';
    %LON2=num2str(lon2);
end
lon1=mod(lon1,360);
lon2=mod(lon2,360);

ok_main_lats_a = (start1 <= lat1) && (lat1 <= end1);
ok_main_lats_b = (start1 <= lat2) && (lat2 <= end1);
ok_main_lats_c = lat1 <= lat2; %lat1 < lat2; 2008/02/18
ok_main_lons_a = (start2 <= lon1) && (lon1 <= end2);
ok_main_lons_b = (start2 <= lon2) && (lon2 <= end2);
ok_main_lons_c = lat1 <= lat2; %lon1 < lon2; 2008/02/18

err_lats = ~(ok_main_lats_a && ok_main_lats_b && ok_main_lats_c);
err_lons = ~(ok_main_lons_a && ok_main_lons_b && ok_main_lons_c);
if (err_lats)
    err=1;
    msg='Latitudes entered are not valid. Please correct and re-enter.';
    return
end
if (err_lons)
    err=1;
    msg='Longitudes entered are not valid. Please correct and re-enter.';
    return
end

%% DATEINC, LATINC, LONINC.
ok_timeinc = (rem(str2num(DATEINC),1)==0);
ok_latinc  = (rem(str2num(LATINC),1)==0);
ok_loninc  = (rem(str2num(LONINC),1)==0);

if (~ok_timeinc)
    err=1;
    msg='Time step must be an integer. Please correct and re-enter.';
    return
end
if (~ok_latinc)
    err=1;
    msg='Latitude step must be an integer. Please correct and re-enter.';
    return
end
if (~ok_loninc)
    err=1;
    msg='Longitude step must be an integer. Please correct and re-enter.';
    return
end

%% SaveWorkspace, SaveFile, Other.
ok_save = SaveWorkspace | SaveFile;
if ~(ok_save)
    err=1;
    msg='Data must be saved in some fashion. Please select how your data is to be saved.';
    return
end

% Request Vector.
request = struct('DATE1',DATE1,...
                 'DATE2',DATE2,...
                 'DATEINC',DATEINC,...
                 'LAT1',LAT1,...
                 'LAT2',LAT2,...
                 'LATINC',LATINC,...
                 'LON1',LON1,...
                 'LON2',LON2,...
                 'LONINC',LONINC,...
                 'DataType',DataType,...
                 'Field',Field,...
                 'Pass',Pass,...
                 'Attributes',Attributes,...
                 'SaveWorkspace',SaveWorkspace,...
                 'SaveWorkspaceMode',SaveWorkspaceMode,...
                 'SaveFile',SaveFile,...
                 'SaveFileType',SaveFileType,...
                 'DIRNAME',directory,...
                 'FNPREFIX',prefx);
    
return %endoffunction
%==========================================================================
function [msg,err,DATE1,DATE2]=qscat_get_dates
% This function determines dates available by calling the catalogs assoc.
% ated with the data product.
%
% DATE1 -- start date for data
% DATE2 -- end date for data
%
% Christian Buckingham
% OPeNDAP 2006

instrument_name='QuikSCAT_L3';

url_catalog='http://dods.jpl.nasa.gov/dods-bin/nph-dods/catalogs/quikscat/L3/quikscat_L3.dat';
url_projection2='year';
url_projection3='month';
url_projection4='day';

% DATE=datestr(now,29);
% date=strrep(DATE,'-','/');

loaddap('+v',[url_catalog,'?',url_projection2,',',url_projection2,',',url_projection3,...
    ',',url_projection4]);

if (~exist(instrument_name))
    msg = ['loaddap connection could not be made. Please try again at a ',...
        'later time or check the connection.'];
    err=1;
    DATE1=[];
    DATE2=[];
    return
end

yyyy=eval([instrument_name,'.year']);
mm=eval([instrument_name,'.month']);
dd=eval([instrument_name,'.day']);

len=length(yyyy);
Y1=num2str(yyyy(1));
M1=num2str(mm(1));
D1=num2str(dd(1));
Y2=num2str(yyyy(len));
M2=num2str(mm(len));
D2=num2str(dd(len));

if (length(M1)==1); M1=['0',M1]; end
if (length(D1)==1); D1=['0',D1]; end

if (length(M2)==1); M2=['0',M2]; end
if (length(D2)==1); D2=['0',D2]; end

DATE1=[Y1,M1,D1];
DATE2=[Y2,M2,D2];

msg='';
err=0;

if (length(DATE1)~=8 || length(DATE2)~=8)
    msg = 'error: problem with QuikSCAT catalog file.';
    err = 1;
    return
end

return
%==========================================================================
function [msg,err,DATE1,DATE2]=adeos_get_dates
% This function determines dates available by calling the catalogs assoc.
% ated with the data product.
%
% DATE1 -- start date for data
% DATE2 -- end date for data
%
% Christian Buckingham
% OPeNDAP 2006

instrument_name='seawinds_L3';

url_catalog='http://dods.jpl.nasa.gov/dods-bin/nph-dods/catalogs/seawinds/L3/seawinds_L3.dat';
url_projection2='year';
url_projection3='month';
url_projection4='day';

% DATE=datestr(now,29);
% date=strrep(DATE,'-','/');

loaddap('+v',[url_catalog,'?',url_projection2,',',url_projection2,',',url_projection3,...
    ',',url_projection4]);

if (~exist(instrument_name))
    msg = ['loaddap connection could not be made. Please try again at a ',...
        'later time or check the connection.'];
    err=1;
    DATE1=[];
    DATE2=[];
    return
end

yyyy=eval([instrument_name,'.year']);
mm=eval([instrument_name,'.month']);
dd=eval([instrument_name,'.day']);

len=length(yyyy);
Y1=num2str(yyyy(1));
M1=num2str(mm(1));
D1=num2str(dd(1));
Y2=num2str(yyyy(len));
M2=num2str(mm(len));
D2=num2str(dd(len));

if (length(M1)==1); M1=['0',M1]; end
if (length(D1)==1); D1=['0',D1]; end

if (length(M2)==1); M2=['0',M2]; end
if (length(D2)==1); D2=['0',D2]; end

DATE1=[Y1,M1,D1];
DATE2=[Y2,M2,D2];

msg='';
err=0;

if (length(DATE1)~=8 || length(DATE2)~=8)
    msg = 'error: problem with Adeos ii catalog file.';
    err = 1;
    return
end

return
%==========================================================================
%==========================================================================
%==========================================================================
%==========================================================================
%==========================================================================


% --- Executes on selection change in popupmenu3.
function popupmenu3_Callback(hObject, eventdata, handles)
function popupmenu3_CreateFcn(hObject, eventdata, handles)

function pushbuttonpodaac_Callback(hObject, eventdata, handles)
% hObject    handle to pushbuttonpodaac (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

url = 'http://dods.jpl.nasa.gov/';
web(url,'-browser')


% --- Executes on button press in pushbuttonInfo.
function pushbuttonInfo_Callback(hObject, eventdata, handles)
% hObject    handle to pushbuttonInfo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
h = op_timemessage('seawinds',0);


% --- Executes on button press in pushbuttonNASA.
function pushbuttonNASA_Callback(hObject, eventdata, handles)
% hObject    handle to pushbuttonNASA (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%web 'http://www.nasa.gov/topics/earth/index.html' -browser
url = 'http://www.nasa.gov/';
web(url,'-browser')